{% extends "keydetail/base.html" %}
{% block keydetail %}
<form method="POST">
    <div class="card-body">
        <div class="form-group">
            <label>Value</label>
            <textarea class="form-control" name="value">{{key_details.data}}</textarea>
        </div>

    </div>
    <div class="card-footer text-right">
        <button class="btn btn-primary mr-1" type="submit">Submit</button>
    </div>
</form>
{% endblock %}