<!DOCTYPE html>
<html lang="en">

    <head>
        <meta charset="UTF-8">
        <meta content="width=device-width, initial-scale=1, maximum-scale=1, shrink-to-fit=no" name="viewport">
        <title>Flask Redis Board</title>

        <link rel="stylesheet"
            href="{{ url_for('redisboard.static', filename='modules/bootstrap/css/bootstrap.min.css') }}">
        <link rel="stylesheet"
            href="{{ url_for('redisboard.static', filename='modules/fontawesome/css/all.min.css') }}">
        <link rel="stylesheet"
            href="{{ url_for('redisboard.static', filename='modules/jquery-selectric/selectric.css') }}">
        <link rel="stylesheet"
            href="{{ url_for('redisboard.static', filename='modules/izitoast/css/iziToast.min.css') }}">
        <link rel="stylesheet"
            href="{{ url_for('redisboard.static', filename='modules/datatable/dataTables.bootstrap4.min.css') }}">
        <link rel="stylesheet"
            href="{{ url_for('redisboard.static', filename='modules/bootstrap4-editable/css/bootstrap-editable.css') }}">
        <!-- Template CSS -->
        <link rel="stylesheet" href="{{ url_for('redisboard.static', filename='css/style.css') }}">
        <link rel="stylesheet" href="{{ url_for('redisboard.static', filename='css/components.css') }}">

    </head>

    <body class="layout-3">
        <div id="app">
            <div class="main-wrapper container">
                <nav class="navbar navbar-expand-lg navbar-secondary">
                    <div class="container">
                        <ul class="navbar-nav">
                            <li class="nav-item {% if 'info' in request.path %} active {% endif%}">
                                <a href="{{url_for('redisboard.info')}}" class="nav-link"><i
                                        class="far fa-heart"></i><span>Server
                                        Info</span></a>
                            </li>
                            <li class="nav-item dropdown {% if 'db' in request.path %} active {% endif%}">
                                <a href="{{url_for('redisboard.db_detail')}}" data-toggle="dropdown"
                                    class="nav-link has-dropdown"><i class="fas fa-fire"></i><span>Connection</span></a>
                                <ul class="dropdown-menu">
                                    {% for db_id in databases %}
                                    <li class="nav-item"><a href="{{url_for('redisboard.db_detail', db=db_id)}}"
                                            class="nav-link">DB
                                            {{db_id}}</a>
                                    </li>
                                    {% endfor %}
                                </ul>
                            </li>
                            <li class="nav-item {% if 'config' in request.path %} active {% endif%}">
                                <a href="{{url_for('redisboard.config')}}" class="nav-link"><i
                                        class="fas fa-cogs"></i><span>Redis Config</span></a>
                            </li>
                        </ul>
                    </div>
                </nav>

                <!-- Main Content -->
                <div class="main-content">
                    {% block content %}
                    {% endblock content %}
                </div>
            </div>
        </div>
        <script src="{{ url_for('redisboard.static', filename='modules/js.cookie.min.js') }}"></script>
        <script src="{{ url_for('redisboard.static', filename='modules/jquery.min.js') }}"></script>
        <script
            src="{{ url_for('redisboard.static', filename='modules/datatable/jquery.dataTables.min.js') }}"></script>
        <script
            src="{{ url_for('redisboard.static', filename='modules/datatable/dataTables.bootstrap4.min.js') }}"></script>
        <script src="{{ url_for('redisboard.static', filename='modules/popper.js') }}"></script>
        <script src="{{ url_for('redisboard.static', filename='modules/tooltip.js') }}"></script>
        <script src="{{ url_for('redisboard.static', filename='modules/bootstrap/js/bootstrap.min.js') }}"></script>
        <script src="{{ url_for('redisboard.static', filename='js/stisla.js') }}"></script>
        <script
            src="{{ url_for('redisboard.static', filename='modules/jquery-selectric/jquery.selectric.min.js') }}"></script>
        <script src="{{ url_for('redisboard.static', filename='modules/izitoast/js/iziToast.min.js') }}"></script>
        <script
            src="{{ url_for('redisboard.static', filename='modules/bootstrap4-editable/js/bootstrap-editable.min.js') }}"></script>

        <script src="{{ url_for('redisboard.static', filename='js/scripts.js') }}"></script>
        <script src="{{ url_for('redisboard.static', filename='js/custom.js') }}"></script>
        {% block js %}
        {% endblock js %}
    </body>

</html>