{% macro render_config_item(config, name) %}
<thead>
    <tr>
        <th colspan="2">{{name}}</th>
    </tr>
</thead>
{% for k,v in config.items() %}
<tr>
    <td width="30%">{{k}} <span class="float-right"><i class="far fa-question-circle" data-toggle="tooltip"
                data-original-title="{{ v.desc }}"></i></span>
    </td>
    <td class="text-center">
        {% if v.can_edit %}
        <a href="#" id="{{k}}" class="myeditable" data-name="{{k}}" data-type="{{v.type}}"
            data-url="{{url_for('redisboard.config')}}">{{v.value}}</a></td>
    {% elif v.value =='' %}
    not set
    {% else %}
    {{v.value}}
    {% endif %}
</tr>
{% endfor %}
{% endmacro %}