{% extends "keydetail/base.html" %}
{% block keydetail %}
<div class="card-header">
    <h4></h4>
    <div class="card-header-action">
        <a href="#" class="btn btn-primary" id="set-add-btn"><i class="fas fa-plus"></i>Add</a>
        <a href="#" class="btn btn-danger" id="set-del-btn"><i class="fas fa-trash"></i>Remove</a>
    </div>
</div>
<div class="card-body">
    {{key_details.data}}
</div>


<form class="modal-part" id="set-add-value">
    <div class="form-group">
        <label>Value</label>
        <div class="input-group">
            <input type="text" class="form-control" name="value" required>
        </div>
        <small class="form-text text-muted">Separate multiple values with ","</small>
    </div>
</form>

<form class="modal-part" id="set-del-value">
    <div class="form-group">
        <label>Value</label>
        <div class="input-group">
            <input type="text" class="form-control" name="value" required>
        </div>
        <small class="form-text text-muted">Separate multiple values with ","</small>
    </div>
</form>

{% endblock %}